pub struct BatteryWatchResponse {
pub status: Status,
pub wake_lease: Option<EventPair>,
}Fields
status: Statuswake_lease: Option<EventPair>Trait Implementations
Sourceimpl Debug for BatteryWatchResponse
impl Debug for BatteryWatchResponse
Sourceimpl Decode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for BatteryWatchResponse
impl Decode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for BatteryWatchResponse
Sourceimpl Encode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for &mut BatteryWatchResponse
impl Encode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for &mut BatteryWatchResponse
Sourceimpl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<Status, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<EventPair, { _ }, 16387>>, DefaultFuchsiaResourceDialect>> Encode<BatteryWatchResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl PartialEq for BatteryWatchResponse
impl PartialEq for BatteryWatchResponse
Sourcefn eq(&self, other: &BatteryWatchResponse) -> bool
fn eq(&self, other: &BatteryWatchResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for BatteryWatchResponse
impl ResourceTypeMarker for BatteryWatchResponse
Sourcetype Borrowed<'a> = &'a mut BatteryWatchResponse
type Borrowed<'a> = &'a mut BatteryWatchResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for BatteryWatchResponse
impl TypeMarker for BatteryWatchResponse
Sourcetype Owned = BatteryWatchResponse
type Owned = BatteryWatchResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for BatteryWatchResponse
impl StructuralPartialEq for BatteryWatchResponse